<?php 

class PutValidConfirm {
  private $scope;
  private $position;
  private $label;
  private $idProp;
  private $confirmModal;

  public function __construct ($entry) {
    if (isset($entry)) {
      $this->scope    = $entry->scope;
      $this->headText = $entry->headText;
      $this->bodyText = $entry->bodyText;
      $this->disabled = $entry->disabled;
      $this->iterator = $entry->iterator;
      $this->idProp   = $entry->idProp;
      $this->label    = $entry->label;
      $this->defLab   = explode ("_", $entry->label)[0];

      $this->mandatory = "{";
      if (isset($entry->mandatory)) {
        $mandatories = explode(",", $entry->mandatory);
        for ($i=0; $i<count($mandatories); $i++) {
          if ($i == 0)    
            $this->mandatory .= $mandatories[$i] . ":0";
          else
            $this->mandatory .= "," . $mandatories[$i] . ":0";
        }
      }    
      $this->mandatory .= "}";

      if (isset($entry->position) && $entry->position == "left")
        $this->position = "left";
      else
        $this->position = "right";
    
      if (isset($entry->confirmModal)) 
        $this->confirmModal = $entry->confirmModal;
      else
        $this->confirmModal = 0;
        
      $this->modalTemplate = " \
  <div class='modal fade' id='cnfModal$this->scope' tabindex='-1' role='dialog'> \
    <div class='modal-dialog modal-sm' role='document'> \
      <div class='modal-content'> \
        <div class='modal-header'> \
          <button type='button' class='close' data-dismiss='modal' \
            onclick='putaction$this->scope(false);'>&times;</button> \
          <h4 class='modal-title'>$this->headText</h4> \
        </div> \
        <div class='modal-body'> \
          <label>$this->bodyText \
          <button type='button' data-dismiss='modal' class='btn btn-inverse' \
            onclick='putaction$this->scope(true);' \
            style='width:70px;'>OK</button> \
          <button type='button' data-dismiss='modal' class='btn btn-inverse' \
            onclick='putaction$this->scope(false);' \
            style='width:70px;'>Cancel</button> \
          </label> \
        </div> \
      </div> \
    </div> \
  </div> \
      ";
    }
  }
  
  public function outputLayout() {
  
    $html = "
<button id='$this->idProp' class='btn btn-inverse' value='$this->label'
  onclick='valid$this->scope();' style='float:$this->position;'>
  $this->defLab
</button>
    ";

  	return $html;
  }
  
  public function outputScript() {
		
    $script = " 	 

var template = \"$this->modalTemplate\";

$(document).ready(function() {
});

var mandatory = $this->mandatory;    
var reply = [];
reply.update = false;
reply.reset = false;

function valid$this->scope () {
  reply.valid = true;
  reply.invalidMsg = ''; 
  for (var key in mandatory) {
//alert (key + '  ' +  mandatory[key]); 
    if (mandatory[key] == 0) {
      reply.valid = false;
      reply.invalidMsg += ' Missing ' + key;  
    }
  }

  if (reply.valid && reply.update && $this->confirmModal) {
    $('body').append(template);
    $('#cnfModal$this->scope').modal('show'); 
  }   
  else if (reply.valid) {
    reply.update = true;
    putaction$this->scope (true);
  }  
  else {
    reply.update = false;
    putaction$this->scope (true);
  }    
}


function putaction$this->scope (ok) {
  if (!ok) {
    reply.update = false;
    reply.reset = true;
  }
  
  action$this->iterator(reply); 

  reply.update = false;
}

function listener$this->scope (message) {
  var key = Object.keys(message); 
//alert (mandatory[key] + '  ' + message[key]);
  if (mandatory[key] != 0 && mandatory[key] != message[key])
    reply.update = true;

  mandatory[key] = message[key];

}

    ";
    return $script;
  }
}

?>
